@@ -1,7 +1,7 @@
-__version__ = '1.1.1'
+__version__ = '1.2.2'
 __author__ = 'ZephyrOff  (Alexandre Pajak)'
 __descriptor__ = 'Générateur de menu à touches fléchées'
-__lastupdate__ = '24/08/2022'
-__releasenote__ = 'Patch windows terminal mode'
+__lastupdate__ = '23/12/2022'
+__releasenote__ = 'Patch size of menu element'
 
 from .menu import *
\ No newline at end of file
